==> d3-4.0.0-rc.2.jar: META-INF/resources/webjars/d3/4.0.0-rc.2/index.js <==
export {
  version
} from "./build/package";

export {
  bisect,
  bisectRight,
  bisectLeft,
  ascending,
  bisector,
  descending,
  deviation,
  extent,
  histogram,
  thresholdFreedmanDiaconis,
  thresholdScott,
  thresholdSturges,
  max,
  mean,
  median,
  merge,
  min,
  pairs,
  permute,
  quantile,
  range,
  scan,
  shuffle,
  sum,
  ticks,
  tickStep,
  transpose,
  variance,
  zip
} from "d3-array";

export {
  entries,
  keys,
  values,
  map,
  set,
  nest
} from "d3-collection";

export {
  randomUniform,
  randomNormal,
  randomLogNormal,
  randomBates,
  randomIrwinHall,
  randomExponential
} from "d3-random";

export {
  easeLinear,
  easeQuad,
  easeQuadIn,
  easeQuadOut,
  easeQuadInOut,
  easeCubic,
  easeCubicIn,
  easeCubicOut,
  easeCubicInOut,
  easePoly,
  easePolyIn,
  easePolyOut,
  easePolyInOut,
  easeSin,
  easeSinIn,
  easeSinOut,
  easeSinInOut,
  easeExp,
  easeExpIn,
  easeExpOut,
  easeExpInOut,
  easeCircle,
  easeCircleIn,
  easeCircleOut,
  easeCircleInOut,
  easeBounce,
  easeBounceIn,
  easeBounceOut,
  easeBounceInOut,
  easeBack,
  easeBackIn,
  easeBackOut,
  easeBackInOut,
  easeElastic,
  easeElasticIn,
  easeElasticOut,
  easeElasticInOut
} from "d3-ease";

export {
  polygonArea,
  polygonCentroid,
  polygonHull,
  polygonContains,
  polygonLength
} from "d3-polygon";

export {
  path
} from "d3-path";

export {
  quadtree
} from "d3-quadtree";

export {
  queue
} from "d3-queue";

export {
  arc,
  area,
  line,
  pie,
  radialArea,
  radialLine,
  symbol,
  symbols,
  symbolCircle,
  symbolCross,
  symbolDiamond,
  symbolSquare,
  symbolStar,
  symbolTriangle,
  symbolWye,
  curveBasisClosed,
  curveBasisOpen,
  curveBasis,
  curveBundle,
  curveCardinalClosed,
  curveCardinalOpen,
  curveCardinal,
  curveCatmullRomClosed,
  curveCatmullRomOpen,
  curveCatmullRom,
  curveLinearClosed,
  curveLinear,
  curveMonotoneX,
  curveMonotoneY,
  curveNatural,
  curveStep,
  curveStepAfter,
  curveStepBefore,
  stack,
  stackOffsetExpand,
  stackOffsetNone,
  stackOffsetSilhouette,
  stackOffsetWiggle,
  stackOrderAscending,
  stackOrderDescending,
  stackOrderInsideOut,
  stackOrderNone,
  stackOrderReverse
} from "d3-shape"

export {
  color,
  rgb,
  hsl,
  lab,
  hcl,
  cubehelix
} from "d3-color";

export {
  interpolate,
  interpolateArray,
  interpolateNumber,
  interpolateObject,
  interpolateRound,
  interpolateString,
  interpolateTransformCss,
  interpolateTransformSvg,
  interpolateZoom,
  interpolateRgb,
  interpolateRgbBasis,
  interpolateRgbBasisClosed,
  interpolateHsl,
  interpolateHslLong,
  interpolateLab,
  interpolateHcl,
  interpolateHclLong,
  interpolateCubehelix,
  interpolateCubehelixLong,
  interpolateBasis,
  interpolateBasisClosed,
  quantize
} from "d3-interpolate";

export {
  dispatch
} from "d3-dispatch";

export {
  dsvFormat,
  csvParse,
  csvParseRows,
  csvFormat,
  csvFormatRows,
  tsvParse,
  tsvParseRows,
  tsvFormat,
  tsvFormatRows
} from "d3-dsv";

export {
  request,
  html,
  json,
  text,
  xml,
  csv,
  tsv
} from "d3-request";

export {
  now,
  timer,
  timerFlush,
  timeout,
  interval
} from "d3-timer";

export {
  timeInterval,
  timeMillisecond,
  timeMilliseconds,
  timeSecond,
  timeSeconds,
  timeMinute,
  timeMinutes,
  timeHour,
  timeHours,
  timeDay,
  timeDays,
  timeWeek,
  timeWeeks,
  timeSunday,
  timeSundays,
  timeMonday,
  timeMondays,
  timeTuesday,
  timeTuesdays,
  timeWednesday,
  timeWednesdays,
  timeThursday,
  timeThursdays,
  timeFriday,
  timeFridays,
  timeSaturday,
  timeSaturdays,
  timeMonth,
  timeMonths,
  timeYear,
  timeYears,
  utcMillisecond,
  utcMilliseconds,
  utcSecond,
  utcSeconds,
  utcMinute,
  utcMinutes,
  utcHour,
  utcHours,
  utcDay,
  utcDays,
  utcWeek,
  utcWeeks,
  utcSunday,
  utcSundays,
  utcMonday,
  utcMondays,
  utcTuesday,
  utcTuesdays,
  utcWednesday,
  utcWednesdays,
  utcThursday,
  utcThursdays,
  utcFriday,
  utcFridays,
  utcSaturday,
  utcSaturdays,
  utcMonth,
  utcMonths,
  utcYear,
  utcYears
} from "d3-time";

export {
  format,
  formatPrefix,
  formatLocale,
  formatDefaultLocale,
  formatSpecifier,
  precisionFixed,
  precisionPrefix,
  precisionRound
} from "d3-format";

export {
  timeFormat,
  timeParse,
  utcFormat,
  utcParse,
  isoFormat,
  isoParse,
  timeFormatLocale,
  timeFormatDefaultLocale
} from "d3-time-format";

export {
  scaleBand,
  scalePoint,
  scaleIdentity,
  scaleLinear,
  scaleLog,
  scaleOrdinal,
  scaleImplicit,
  scalePow,
  scaleSqrt,
  scaleQuantile,
  scaleQuantize,
  scaleThreshold,
  scaleTime,
  scaleUtc,
  schemeCategory10,
  schemeCategory20b,
  schemeCategory20c,
  schemeCategory20,
  scaleSequential,
  interpolateCubehelixDefault,
  interpolateRainbow,
  interpolateWarm,
  interpolateCool,
  interpolateViridis,
  interpolateMagma,
  interpolateInferno,
  interpolatePlasma
} from "d3-scale";

export {
  creator,
  customEvent,
  event,
  local,
  matcher,
  mouse,
  namespace,
  namespaces,
  select,
  selectAll,
  selection,
  selector,
  selectorAll,
  touch,
  touches,
  window
} from "d3-selection";

export {
  active,
  interrupt,
  transition
} from "d3-transition";

export {
  axisTop,
  axisRight,
  axisBottom,
  axisLeft
} from "d3-axis";

export {
  cluster,
  hierarchy,
  pack,
  packSiblings,
  packEnclose,
  partition,
  stratify,
  tree,
  treemap,
  treemapBinary,
  treemapDice,
  treemapSlice,
  treemapSliceDice,
  treemapSquarify,
  treemapResquarify
} from "d3-hierarchy";

export {
  forceCenter,
  forceCollide,
  forceLink,
  forceManyBody,
  forceSimulation,
  forceX,
  forceY
} from "d3-force";

export {
  drag,
  dragDisable,
  dragEnable
} from "d3-drag";

export {
  voronoi
} from "d3-voronoi";

export {
  zoom,
  zoomIdentity,
  zoomTransform
} from "d3-zoom";

export {
  brush,
  brushX,
  brushY,
  brushSelection
} from "d3-brush";

export {
  geoArea,
  geoBounds,
  geoCentroid,
  geoCircle,
  geoClipExtent,
  geoDistance,
  geoGraticule,
  geoInterpolate,
  geoLength,
  geoPath,
  geoAlbers,
  geoAlbersUsa,
  geoAzimuthalEqualArea,
  geoAzimuthalEquidistant,
  geoConicConformal,
  geoConicEqualArea,
  geoConicEquidistant,
  geoEquirectangular,
  geoGnomonic,
  geoProjection,
  geoProjectionMutator,
  geoMercator,
  geoOrthographic,
  geoStereographic,
  geoTransverseMercator,
  geoRotation,
  geoStream,
  geoTransform
} from "d3-geo";

==> d3-4.2.0.jar: META-INF/resources/webjars/d3/4.2.0/index.js <==
export {
  version
} from "./build/package";

export {
  bisect,
  bisectRight,
  bisectLeft,
  ascending,
  bisector,
  descending,
  deviation,
  extent,
  histogram,
  thresholdFreedmanDiaconis,
  thresholdScott,
  thresholdSturges,
  max,
  mean,
  median,
  merge,
  min,
  pairs,
  permute,
  quantile,
  range,
  scan,
  shuffle,
  sum,
  ticks,
  tickStep,
  transpose,
  variance,
  zip
} from "d3-array";

export {
  entries,
  keys,
  values,
  map,
  set,
  nest
} from "d3-collection";

export {
  randomUniform,
  randomNormal,
  randomLogNormal,
  randomBates,
  randomIrwinHall,
  randomExponential
} from "d3-random";

export {
  easeLinear,
  easeQuad,
  easeQuadIn,
  easeQuadOut,
  easeQuadInOut,
  easeCubic,
  easeCubicIn,
  easeCubicOut,
  easeCubicInOut,
  easePoly,
  easePolyIn,
  easePolyOut,
  easePolyInOut,
  easeSin,
  easeSinIn,
  easeSinOut,
  easeSinInOut,
  easeExp,
  easeExpIn,
  easeExpOut,
  easeExpInOut,
  easeCircle,
  easeCircleIn,
  easeCircleOut,
  easeCircleInOut,
  easeBounce,
  easeBounceIn,
  easeBounceOut,
  easeBounceInOut,
  easeBack,
  easeBackIn,
  easeBackOut,
  easeBackInOut,
  easeElastic,
  easeElasticIn,
  easeElasticOut,
  easeElasticInOut
} from "d3-ease";

export {
  polygonArea,
  polygonCentroid,
  polygonHull,
  polygonContains,
  polygonLength
} from "d3-polygon";

export {
  path
} from "d3-path";

export {
  quadtree
} from "d3-quadtree";

export {
  queue
} from "d3-queue";

export {
  arc,
  area,
  line,
  pie,
  radialArea,
  radialLine,
  symbol,
  symbols,
  symbolCircle,
  symbolCross,
  symbolDiamond,
  symbolSquare,
  symbolStar,
  symbolTriangle,
  symbolWye,
  curveBasisClosed,
  curveBasisOpen,
  curveBasis,
  curveBundle,
  curveCardinalClosed,
  curveCardinalOpen,
  curveCardinal,
  curveCatmullRomClosed,
  curveCatmullRomOpen,
  curveCatmullRom,
  curveLinearClosed,
  curveLinear,
  curveMonotoneX,
  curveMonotoneY,
  curveNatural,
  curveStep,
  curveStepAfter,
  curveStepBefore,
  stack,
  stackOffsetExpand,
  stackOffsetNone,
  stackOffsetSilhouette,
  stackOffsetWiggle,
  stackOrderAscending,
  stackOrderDescending,
  stackOrderInsideOut,
  stackOrderNone,
  stackOrderReverse
} from "d3-shape"

export {
  color,
  rgb,
  hsl,
  lab,
  hcl,
  cubehelix
} from "d3-color";

export {
  interpolate,
  interpolateArray,
  interpolateDate,
  interpolateNumber,
  interpolateObject,
  interpolateRound,
  interpolateString,
  interpolateTransformCss,
  interpolateTransformSvg,
  interpolateZoom,
  interpolateRgb,
  interpolateRgbBasis,
  interpolateRgbBasisClosed,
  interpolateHsl,
  interpolateHslLong,
  interpolateLab,
  interpolateHcl,
  interpolateHclLong,
  interpolateCubehelix,
  interpolateCubehelixLong,
  interpolateBasis,
  interpolateBasisClosed,
  quantize
} from "d3-interpolate";

export {
  dispatch
} from "d3-dispatch";

export {
  dsvFormat,
  csvParse,
  csvParseRows,
  csvFormat,
  csvFormatRows,
  tsvParse,
  tsvParseRows,
  tsvFormat,
  tsvFormatRows
} from "d3-dsv";

export {
  request,
  html,
  json,
  text,
  xml,
  csv,
  tsv
} from "d3-request";

export {
  now,
  timer,
  timerFlush,
  timeout,
  interval
} from "d3-timer";

export {
  timeInterval,
  timeMillisecond,
  timeMilliseconds,
  timeSecond,
  timeSeconds,
  timeMinute,
  timeMinutes,
  timeHour,
  timeHours,
  timeDay,
  timeDays,
  timeWeek,
  timeWeeks,
  timeSunday,
  timeSundays,
  timeMonday,
  timeMondays,
  timeTuesday,
  timeTuesdays,
  timeWednesday,
  timeWednesdays,
  timeThursday,
  timeThursdays,
  timeFriday,
  timeFridays,
  timeSaturday,
  timeSaturdays,
  timeMonth,
  timeMonths,
  timeYear,
  timeYears,
  utcMillisecond,
  utcMilliseconds,
  utcSecond,
  utcSeconds,
  utcMinute,
  utcMinutes,
  utcHour,
  utcHours,
  utcDay,
  utcDays,
  utcWeek,
  utcWeeks,
  utcSunday,
  utcSundays,
  utcMonday,
  utcMondays,
  utcTuesday,
  utcTuesdays,
  utcWednesday,
  utcWednesdays,
  utcThursday,
  utcThursdays,
  utcFriday,
  utcFridays,
  utcSaturday,
  utcSaturdays,
  utcMonth,
  utcMonths,
  utcYear,
  utcYears
} from "d3-time";

export {
  format,
  formatPrefix,
  formatLocale,
  formatDefaultLocale,
  formatSpecifier,
  precisionFixed,
  precisionPrefix,
  precisionRound
} from "d3-format";

export {
  timeFormat,
  timeParse,
  utcFormat,
  utcParse,
  isoFormat,
  isoParse,
  timeFormatLocale,
  timeFormatDefaultLocale
} from "d3-time-format";

export {
  scaleBand,
  scalePoint,
  scaleIdentity,
  scaleLinear,
  scaleLog,
  scaleOrdinal,
  scaleImplicit,
  scalePow,
  scaleSqrt,
  scaleQuantile,
  scaleQuantize,
  scaleThreshold,
  scaleTime,
  scaleUtc,
  schemeCategory10,
  schemeCategory20b,
  schemeCategory20c,
  schemeCategory20,
  scaleSequential,
  interpolateCubehelixDefault,
  interpolateRainbow,
  interpolateWarm,
  interpolateCool,
  interpolateViridis,
  interpolateMagma,
  interpolateInferno,
  interpolatePlasma
} from "d3-scale";

export {
  creator,
  customEvent,
  event,
  local,
  matcher,
  mouse,
  namespace,
  namespaces,
  select,
  selectAll,
  selection,
  selector,
  selectorAll,
  touch,
  touches,
  window
} from "d3-selection";

export {
  active,
  interrupt,
  transition
} from "d3-transition";

export {
  axisTop,
  axisRight,
  axisBottom,
  axisLeft
} from "d3-axis";

export {
  cluster,
  hierarchy,
  pack,
  packSiblings,
  packEnclose,
  partition,
  stratify,
  tree,
  treemap,
  treemapBinary,
  treemapDice,
  treemapSlice,
  treemapSliceDice,
  treemapSquarify,
  treemapResquarify
} from "d3-hierarchy";

export {
  forceCenter,
  forceCollide,
  forceLink,
  forceManyBody,
  forceSimulation,
  forceX,
  forceY
} from "d3-force";

export {
  drag,
  dragDisable,
  dragEnable
} from "d3-drag";

export {
  voronoi
} from "d3-voronoi";

export {
  zoom,
  zoomIdentity,
  zoomTransform
} from "d3-zoom";

export {
  brush,
  brushX,
  brushY,
  brushSelection
} from "d3-brush";

export {
  chord,
  ribbon
} from "d3-chord";

export {
  geoAlbers,
  geoAlbersUsa,
  geoArea,
  geoAzimuthalEqualArea,
  geoAzimuthalEqualAreaRaw,
  geoAzimuthalEquidistant,
  geoAzimuthalEquidistantRaw,
  geoBounds,
  geoCentroid,
  geoCircle,
  geoClipExtent,
  geoConicConformal,
  geoConicConformalRaw,
  geoConicEqualArea,
  geoConicEqualAreaRaw,
  geoConicEquidistant,
  geoConicEquidistantRaw,
  geoDistance,
  geoEquirectangular,
  geoEquirectangularRaw,
  geoGnomonic,
  geoGnomonicRaw,
  geoGraticule,
  geoInterpolate,
  geoLength,
  geoMercator,
  geoMercatorRaw,
  geoOrthographic,
  geoOrthographicRaw,
  geoPath,
  geoProjection,
  geoProjectionMutator,
  geoRotation,
  geoStereographic,
  geoStereographicRaw,
  geoStream,
  geoTransform,
  geoTransverseMercator,
  geoTransverseMercatorRaw
} from "d3-geo";
